@@ -102,6 +102,11 @@ extern "C"
     XLAPI            int XLAPIENTRY xlSheetRemoveColA(SheetHandle handle, int colFirst, int colLast);
     XLAPI            int XLAPIENTRY xlSheetRemoveRowA(SheetHandle handle, int rowFirst, int rowLast);
 
+ XLAPI            int XLAPIENTRY xlSheetInsertColAndKeepRangesA(SheetHandle handle, int colFirst, int colLast);
+    XLAPI            int XLAPIENTRY xlSheetInsertRowAndKeepRangesA(SheetHandle handle, int rowFirst, int rowLast);
+    XLAPI            int XLAPIENTRY xlSheetRemoveColAndKeepRangesA(SheetHandle handle, int colFirst, int colLast);
+    XLAPI            int XLAPIENTRY xlSheetRemoveRowAndKeepRangesA(SheetHandle handle, int rowFirst, int rowLast);
+
     XLAPI            int XLAPIENTRY xlSheetCopyCellA(SheetHandle handle, int rowSrc, int colSrc, int rowDst, int colDst);
 
     XLAPI            int XLAPIENTRY xlSheetFirstRowA(SheetHandle handle);
