@@ -6,7 +6,7 @@
 
 extern PyTypeObject XLPyFormatType;
 
-enum Position { LEFT, RIGHT, TOP, BOTTOM };
+enum MarginSide { LEFT, RIGHT, TOP, BOTTOM };
 
 static int
 init(XLPySheet *self)
@@ -458,7 +458,7 @@ set_picture(XLPySheet *self, PyObject *args)
     }
 
     xlSheetSetPicture(self->handler, row, col,
-            pictureId, scale, offset_x, offset_y);
+            pictureId, scale, offset_x, offset_y, 0);
     Py_RETURN_NONE;
 }
 
@@ -474,7 +474,7 @@ set_picture_2(XLPySheet *self, PyObject *args)
     }
 
     xlSheetSetPicture2(self->handler, row, col,
-            pictureId, width, height, offset_x, offset_y);
+            pictureId, width, height, offset_x, offset_y, 0);
     Py_RETURN_NONE;
 }
 
