@@ -22,7 +22,7 @@ extern "C"
     XLAPI            int XLAPIENTRY xlBookLoadPartiallyW(BookHandle handle, const wchar_t* filename, int sheetIndex, int firstRow, int lastRow);
     XLAPI            int XLAPIENTRY xlBookLoadPartiallyUsingTempFileW(BookHandle handle, const wchar_t* filename, int sheetIndex, int firstRow, int lastRow, const wchar_t* tempFile);
 
-    XLAPI            int XLAPIENTRY xlBookLoadWithoutEmptyCellsW(BookHandle handle, const wchar_t* filename);
+    XLAPI            int XLAPIENTRY xlBookLoadInfoW(BookHandle handle, const wchar_t* filename);
 
     XLAPI            int XLAPIENTRY xlBookLoadRawW(BookHandle handle, const char* data, unsigned size);
     XLAPI            int XLAPIENTRY xlBookLoadRawPartiallyW(BookHandle handle, const char* data, unsigned size, int sheetIndex, int firstRow, int lastRow);
@@ -31,6 +31,7 @@ extern "C"
     XLAPI    SheetHandle XLAPIENTRY xlBookAddSheetW(BookHandle handle, const wchar_t* name, SheetHandle initSheet);
     XLAPI    SheetHandle XLAPIENTRY xlBookInsertSheetW(BookHandle handle, int index, const wchar_t* name, SheetHandle initSheet);
     XLAPI    SheetHandle XLAPIENTRY xlBookGetSheetW(BookHandle handle, int index);
+    XLAPI const wchar_t* XLAPIENTRY xlBookGetSheetNameW(BookHandle handle, int index);
     XLAPI            int XLAPIENTRY xlBookSheetTypeW(BookHandle handle, int index);
     XLAPI            int XLAPIENTRY xlBookMoveSheetW(BookHandle handle, int srcIndex, int dstIndex);
     XLAPI            int XLAPIENTRY xlBookDelSheetW(BookHandle handle, int index);
