@@ -100,10 +100,10 @@ namespace libxl
 
         virtual             bool XLAPIENTRY clear(int rowFirst = 0, int rowLast = 1048575, int colFirst = 0, int colLast = 16383) = 0;
 
-        virtual             bool XLAPIENTRY insertCol(int colFirst, int colLast) = 0;
-        virtual             bool XLAPIENTRY insertRow(int rowFirst, int rowLast) = 0;
-        virtual             bool XLAPIENTRY removeCol(int colFirst, int colLast) = 0;
-        virtual             bool XLAPIENTRY removeRow(int rowFirst, int rowLast) = 0;
+        virtual             bool XLAPIENTRY insertCol(int colFirst, int colLast, bool updateNamedRanges = true) = 0;
+  virtual             bool XLAPIENTRY insertRow(int rowFirst, int rowLast, bool updateNamedRanges = true) = 0;
+  virtual             bool XLAPIENTRY removeCol(int colFirst, int colLast, bool updateNamedRanges = true) = 0;
+  virtual             bool XLAPIENTRY removeRow(int rowFirst, int rowLast, bool updateNamedRanges = true) = 0;
 
         virtual             bool XLAPIENTRY copyCell(int rowSrc, int colSrc, int rowDst, int colDst) = 0;
 
